@@ -189,9 +189,7 @@ sub getRelatedness
 
     #  calculate the distance
     my $distance = ($ic1 + $ic2) - (2 * $iclcs);
-    my $a = $ic1 + $ic2;
-    my $b = 2 * $iclcs;
-    my $c = 1 / $distance; 
+
     # if the distance is zero 
     # implies ic1 == ic2 == ic3 (most probably all three represent
     # the same concept)... i.e. maximum relatedness... i.e. infinity...
