@@ -29,7 +29,7 @@ Optional command line arguements
 
 This is the configuration file. There are six configuration options 
 that can be used depending on which measure you are using. The 
-path, wup, zhong, lch, lin, jcn and res measures require the SAB 
+path, wup, cmatch, zhong, lch, lin, jcn and res measures require the SAB 
 and REL options to be set while the vector and lesk measures require 
 the SABDEF and RELDEF options. 
 
@@ -121,6 +121,11 @@ available measure are:
     9. Lin (1988) referred to as lin
     10 Jiang and Conrath (1997) referred to as jcn
     11. The vector measure referred to as vector
+    12. Pekar and Staab (2002) referred to as pks
+    13. Pirro and Euzenat (2010) referred to as faith
+    14. Maedche and Staab (2001) referred to as cmatch
+    15. Batet, et al (2011) referred to as batet
+    16. S{\'a}nchez, et al. (2012) referred to as sanchez
 
 =head3 --original
 
@@ -533,7 +538,12 @@ sub calculateSimilarity {
     
     if($debug) { print STDERR "In calculateSimilarity\n"; }
     
-    if(defined $opt_matrix) { print "@input_array\n"; }
+    if(defined $opt_matrix) { 
+	foreach my $el (@input_array) { 
+	    print "$el\t"; 
+	}
+	print "\n";
+    }
 
     my @secondary_array = @input_array;
 
@@ -549,7 +559,7 @@ sub calculateSimilarity {
 	    push @secondary_array, $i2;
 	}
 	else {
-	    print "$input1 ";
+	    print "$input1\t";
 	}
 	
 	foreach $input2 (@secondary_array) {	
@@ -668,7 +678,7 @@ sub calculateSimilarity {
 	    }
 
 	    #  print the matrix
-	    if(defined $opt_matrix) { print "$score "; }
+	    if(defined $opt_matrix) { print "$score\t"; }
 	    #  print all the concepts and their scores
 	    elsif( (defined $opt_allsenses) && ($cc1 ne "" or $cc2 ne "") ) {
 		foreach my $cc1 (sort keys %similarityHash) {
@@ -838,7 +848,7 @@ sub loadMeasures {
     }
     
     #  set the information content options if defined
-    if($measure=~/res|jcn|lin/) { 
+    if($measure=~/res|jcn|lin|faith/) { 
 	if(defined $opt_st) {
 	    $icoptions{"st"} = $opt_st;
 	}
@@ -927,12 +937,36 @@ sub loadMeasures {
 	use UMLS::Similarity::wup;	
 	$meas = UMLS::Similarity::wup->new($umls);
     }    
+    #  loading the module implementing the Maedche and 
+    #  Staab (2001) measure
+    if($measure eq "cmatch") {
+	use UMLS::Similarity::cmatch;	
+	$meas = UMLS::Similarity::cmatch->new($umls);
+    }    
+    #  loading the module implementing the Sanchez, et al.
+    #  (2012) measure
+    if($measure eq "sanchez") {
+	use UMLS::Similarity::sanchez;	
+	$meas = UMLS::Similarity::sanchez->new($umls);
+    }    
+    #  loading module implementing the Batet, et al. (2011)
+    #  measure
+    if($measure eq "batet") {
+	use UMLS::Similarity::batet;	
+	$meas = UMLS::Similarity::batet->new($umls);
+    }    
+    #  loading the module implementing the Pekar and 
+    #  Staab (2002) measure
+    if($measure eq "pks") {
+	use UMLS::Similarity::pks;	
+	$meas = UMLS::Similarity::pks->new($umls);
+    }    
     #  loading the module implementing closeness
     #  modification of wup
-    #if($measure eq "closeness") {
-    #use UMLS::Similarity::closeness;	
-    #$meas = UMLS::Similarity::closeness->new($umls);
-    #}    
+    if($measure eq "closeness") {
+	use UMLS::Similarity::closeness;	
+	$meas = UMLS::Similarity::closeness->new($umls);
+    }    
     #  loading the module implementing the Zhong
     #  et al (2002) measure
     if($measure eq "zhong") {
@@ -981,6 +1015,11 @@ sub loadMeasures {
 	use UMLS::Similarity::lin;
 	$meas = UMLS::Similarity::lin->new($umls, \%icoptions);
     }
+    #  load the module implementing the Perro and Euzenat (2010) measure
+    if($measure eq "faith") {
+	use UMLS::Similarity::faith;
+	$meas = UMLS::Similarity::faith->new($umls, \%icoptions);
+    }
     #  load the module implementing the random measure
     if($measure eq "random") {
 	use UMLS::Similarity::random;
@@ -1112,7 +1151,7 @@ sub checkOptions {
     }
 
     if(defined $opt_measure) {
-	if($opt_measure=~/\b(path|upath|wup|closeness|zhong|lch|cdist|nam|vector|res|lin|random|jcn|lesk|o1vector)\b/) {
+	if($opt_measure=~/\b(path|upath|wup|cmatch|batet|sanchez|pks|closeness|zhong|lch|cdist|nam|vector|res|lin|faith|random|jcn|lesk|o1vector)\b/) {
 	    #  good to go
 	}
 	else {
@@ -1230,10 +1269,10 @@ sub checkOptions {
     #  the icpropagation and icfrequency options can only be used 
     #  with specific measures
     if(defined $opt_icpropagation || defined $opt_icfrequency) { 
-	if( !($opt_measure=~/(res|lin|jcn)/) ) {
+	if( !($opt_measure=~/(res|lin|faith|jcn)/) ) {
 	    print STDERR "The --icpropagation or --icfrequency options\n";
-            print STDERR "may only be specified when using the res, lin\n";
-	    print STDERR "or jcn measures.\n\n";
+            print STDERR "may only be specified when using the res, lin,\n";
+	    print STDERR "jcn or faith measures.\n\n";
 	    &minimalUsageNotes();
 	    exit;
 	}
@@ -1534,8 +1573,13 @@ sub showHelp() {
     print "  8. Resnik (1996) referred to as res\n";
     print "  9. Lin (1988) referred to as lin\n";
     print "  10. Jiang and Conrath (1997) referred to as jcn\n";
-    print "  11. The vector measure referred to as vector\n\n";
-  
+    print "  11. The vector measure referred to as vector\n";
+    print "  12. Pekar and Staab (2002) referred to as pks\n";
+    print "  13. Perro and Euzenat (2010) referred to as faith\n";
+    print "  14. Maedche and Staab (2001) referred to as cmatch\n";
+    print "  15. Batet, et al (2011) referred to as batet\n";
+    print "  16. S{\'a}nchez, et al. (2012) referred to as sanchez\n\n";
+
     print "Usage: umls-similarity.pl [OPTIONS] TERM1 TERM2\n\n";
 
     print "General Options:\n\n";
@@ -1668,7 +1712,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: umls-similarity.pl,v 1.109 2014/07/07 14:54:56 btmcinnes Exp $';
+    print '$Id: umls-similarity.pl,v 1.112 2015/06/23 14:57:59 btmcinnes Exp $';
     print "\nCopyright (c) 2008-2011, Ted Pedersen & Bridget McInnes\n";
 }
 
